#include "counter.hpp"

TapeCounter::TapeCounter(int x, int y, int* count) :
	Icon(x, y, x + TAPE_COUNTER_WIDTH, 
		      y + TAPE_COUNTER_HEIGHT)
{
	// capture the reference to the count value
	tape_count = count;

	// set to a negative value in order to
	// force Update() to shown the initial count
	last_count = -1;

	// create the tape counter box
	box = new ShadedBox(x1, y1,
			    x2 - x1, y2 - y1,
			    BLACK,
			    BRIGHT_RED,
			    GRAY);
}

void TapeCounter::Display()
{
	// show the backdop box
	box->Display();

	// partition off the legend area
	BOX_TYPE area;
	area.x1 = x1 + 2;
	area.y1 = y1 + TAPE_COUNTER_LEGEND_HEIGHT + 2;
	area.x2 = x2 - 2;
	area.y2 = area.y1;
	GraphicsHandler->DrawLine(BRIGHT_RED,
				  SOLID_LINE,
				  &area);

	// display the name of the icon
	Legend value;
	area.y1 = y1;
	value.Center(&area, BRIGHT_RED, "Tape Count");
}

void TapeCounter::Update()
{
	// abort unless the tape count has changed
	if (*tape_count == last_count) return;

	// store value of this tape count
	last_count = *tape_count;

	// erase the previous count
	BOX_TYPE box;
	box.x1 = x1 + 3;
	box.y1 = y1 + TAPE_COUNTER_LEGEND_HEIGHT + 3;
	box.x2 = x2 - 3;
	box.y2 = y2 - 3;
	GraphicsHandler->FillBox(GRAY, &box);

	// display the current count value
	Legend value;
	char string [20];
	sprintf(string, "%d", *tape_count);
	value.Center(&box, BRIGHT_RED, string);
}

TapeCounter::~TapeCounter()
{
	delete box;
}
